==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/tests/Portable_Interceptors/PolicyFactory/PolicyFactory.h <==
// -*- C++ -*-

//=============================================================================
/**
 * @file PolicyFactory.h
 *
 * PolicyFactory.h,v 1.1 2004/07/18 16:26:20 ossama Exp
 *
 * Implementation header for the test policy factory.
 *
 * @author Ossama Othman <ossama@dre.vanderbilt.edu>
 */
//=============================================================================

#ifndef POLICY_FACTORY_H
#define POLICY_FACTORY_H

#include "ace/config-all.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "tao/PortableInterceptorC.h"
#include "tao/LocalObject.h"

#if defined(_MSC_VER)
#if (_MSC_VER >= 1200)
#pragma warning(push)
#endif /* _MSC_VER >= 1200 */
#pragma warning(disable:4250)
#endif /* _MSC_VER */

/**
 * @class PolicyFactory
 *
 * @brief Simple concrete PolicyFactory.
 *
 * This is a test PolicyFactory that constructs a Test::Policy
 * object.
 */
class PolicyFactory
  : public virtual PortableInterceptor::PolicyFactory,
    public virtual TAO_Local_RefCounted_Object
{
public:

  /**
   * @name Methods Required by the PolicyFactory Interface
   *
   * These are methods that must be implemented since they are pure
   * virtual in the abstract base class.  They are the canonical
   * methods required for all PolicyFactory sub-classes.
   */
  //@{

  /// Construct a Test::Policy object as a test.
  virtual CORBA::Policy_ptr create_policy (CORBA::PolicyType type,
                                           const CORBA::Any & value
                                           ACE_ENV_ARG_DECL_WITH_DEFAULTS)
    ACE_THROW_SPEC ((CORBA::SystemException,
                     CORBA::PolicyError));

  //@}

};

#if defined(_MSC_VER) && (_MSC_VER >= 1200)
#pragma warning(pop)
#endif /* _MSC_VER */

#endif  /* POLICY_FACTORY_H */

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/tests/Portable_Interceptors/PolicyFactory/PolicyFactory.h <==
// -*- C++ -*-

//=============================================================================
/**
 * @file PolicyFactory.h
 *
 * PolicyFactory.h,v 1.3 2005/06/14 08:51:23 jwillemsen Exp
 *
 * Implementation header for the test policy factory.
 *
 * @author Ossama Othman <ossama@dre.vanderbilt.edu>
 */
//=============================================================================

#ifndef POLICY_FACTORY_H
#define POLICY_FACTORY_H

#include "ace/config-all.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "tao/PI/PI.h"
#include "tao/LocalObject.h"

#if defined(_MSC_VER)
#pragma warning(push)
#pragma warning(disable:4250)
#endif /* _MSC_VER */

/**
 * @class PolicyFactory
 *
 * @brief Simple concrete PolicyFactory.
 *
 * This is a test PolicyFactory that constructs a Test::Policy
 * object.
 */
class PolicyFactory
  : public virtual PortableInterceptor::PolicyFactory,
    public virtual TAO_Local_RefCounted_Object
{
public:

  /**
   * @name Methods Required by the PolicyFactory Interface
   *
   * These are methods that must be implemented since they are pure
   * virtual in the abstract base class.  They are the canonical
   * methods required for all PolicyFactory sub-classes.
   */
  //@{

  /// Construct a Test::Policy object as a test.
  virtual CORBA::Policy_ptr create_policy (CORBA::PolicyType type,
                                           const CORBA::Any & value
                                           ACE_ENV_ARG_DECL_WITH_DEFAULTS)
    ACE_THROW_SPEC ((CORBA::SystemException,
                     CORBA::PolicyError));

  //@}

};

#if defined(_MSC_VER)
#pragma warning(pop)
#endif /* _MSC_VER */

#endif  /* POLICY_FACTORY_H */
